@@ -18,7 +18,7 @@ except ImportError:
 
 _INLINE = [
     "\*+.*?\*+",    # italic or bold
-    "``.*?``",      # literal
+    "`+.*?`+",      # literal
 ]
 
 _ROLE = [
@@ -27,7 +27,7 @@ _ROLE = [
 
 _HYPER_LINK = [
     "https?://[^ ]+",               # http://xxx
-    "`.*?\s*`__?",                  # `link <http://>`_ , `link`_ or `name`__
+    "`.*?`__?",                     # `link <http://>`_ , `link`_ or `name`__
     "^\.\.\s*_.*?:\s*https?://[^ ]+$",  # .. _link: http://xxx
     "^__\s*https?://[^ ]+$",        # __ http://xxx
 ]
@@ -43,11 +43,14 @@ _REFERENCE = [
 ]
 
 _SOURCE = [
-    ":\s+",     # collon:
+    ":\s*$",    # collon:
+    ":\s+",     # collon: [space]
     "::\s*",    # source::
 ]
 
-_NOTRANSLATE = _INLINE + _ROLE + _HYPER_LINK + _RUBRIC + _REFERENCE + _SOURCE
+# FIXME: it need to match first _HYPERLINK than _LILINE
+#      : because, `link`_ is matched in preference to `literal`
+_NOTRANSLATE = _ROLE + _HYPER_LINK + _INLINE + _RUBRIC + _REFERENCE + _SOURCE
 _NOTRANSLATE_PTRN = re.compile(r"({0})".format("|".join(_NOTRANSLATE)),
                                re.M | re.U)
 
@@ -99,6 +102,7 @@ _DIRECTIVE_WITH_PARAGRAPH = re.compile(r"""(
 
 _EMPTY_LINE = re.compile(r"^\s*$", re.U)
 _LINE_WITH_INDENT = re.compile(r"(^\s+)(.+?)$", re.U)
+_LINE_WITH_INDENT_OR_NONE = re.compile(r"(^\s*)(.+?)$", re.U)
 _PARAGRAPH_START = re.compile(r"^([\S\.]+)(.*?)$", re.U)
 _END_OF_SENTENCE = {
     "en": re.compile(unicode(r".*?[\.\?!]", "utf-8"), re.M | re.U),
@@ -264,7 +268,8 @@ class reSTParser(object):
             num, section = 0, []
             for mline in get_multiline(_lines, 3):
                 match = re.search(_SECTION, "".join(mline))
-                if re.search(_EMPTY_LINE, mline[0]):
+                if re.search(_EMPTY_LINE, mline[0]) or (
+                   mline[1:] and re.search(_EMPTY_LINE, mline[1])):
                     break
                 elif match:
                     d = match.groupdict()
@@ -302,21 +307,27 @@ class reSTApiCaller(object):
         self.lang_to = lang_to
 
     def split_text_into_multiline(self, text):
-        if re.search(_LISTBLOCK, text):
-            # FIXME: need to check indent when a list line is split
-            return [text]
-
+        # FIXME: only valid for paragraph, need for other blocks
         if self.lang_to in ("ja"):
+            def set_indent(lines):
+                indent, _text = self.get_indent_and_text(lines[0])
+                lines[0] = _text  # replace first line with text removed indent
+                _lines = []
+                for line in lines:
+                    line = line[1:] if line[:1] == " " else line
+                    _lines.append(u"{0}{1}\n".format(indent, line))
+                return _lines
+
             text = text.rstrip()
             eos_ptrn = _END_OF_SENTENCE.get(self.lang_to)
-            _lines = re.findall(eos_ptrn, text)
-            if not _lines:
-                _lines = [text]
+            lines = re.findall(eos_ptrn, text)
+            if not lines:
+                lines = [text]
             else:
-                extra_text = text[len(u"".join(_lines)):]
+                extra_text = text[len(u"".join(lines)):]
                 if extra_text:
-                    _lines.append(extra_text)
-            return [u"{0}\n".format(line) for line in _lines]
+                    lines.append(extra_text)
+            return set_indent(lines)
         else:
             indent, _ = self.get_indent_and_text(text)
             dedented_text = textwrap.dedent(text).strip()
@@ -345,38 +356,21 @@ class reSTApiCaller(object):
         return api, u"{0}{1}\n".format(prefix, result[0])
 
     def _call_keeping_prefix_with_array(self, api_method, indents, lines):
-        _texts = []
+        api, trans = None, []
         for pos in range(0, len(indents), self.max_query):
             _idns = indents[pos:pos + self.max_query]
             _lines = lines[pos:pos + self.max_query]
-            api, trans = api_method(_lines)
-            _texts.extend([u"{0}{1}\n".format(*i) for i in zip(_idns, trans)])
-        return api, self.split_lines_with_eos(_texts)
+            api, _trans = api_method(_lines)
+            trans.extend([u"{0}{1}\n".format(*i) for i in zip(_idns, _trans)])
+        return api, trans
 
     def _call_for_directive(self, api_method, block_lines, first):
-        def _concatenate_lines(lines):
-            _lines, prev_indent = [], None
-            for line in lines:
-                match = re.search(_LINE_WITH_INDENT, line)
-                if match:
-                    indent, text = match.groups()
-                    if prev_indent == indent:
-                        # FIXME: need to check list/line block ...
-                        _prev = _lines[-1].rstrip()
-                        _lines[-1] = u"{0} {1}".format(_prev, text)
-                    else:
-                        _lines.append(line)
-                    prev_indent = indent
-                else:
-                    _lines.append(line)
-                    prev_indent = None
-            return _lines
-
         if not re.search(_DIRECTIVE_WITH_PARAGRAPH, first):
             return None, block_lines
 
+        # FIXME: need to check list/line block concatenating ...
         api, indents, lines = None, [], []
-        for line in _concatenate_lines(block_lines[1:]):
+        for line in concatenate_lines(block_lines[1:], _LINE_WITH_INDENT):
             match = re.search(_LINE_WITH_INDENT, line)
             indent, line = self._markup_notranslate(line, match)
             indents.append(indent)
@@ -574,36 +568,16 @@ class reSTApiCaller(object):
             lines.append(line)
         return api, lines
 
-    def _concatenate_paragraph_line(self, lines):
-        _lines, prev_indent = [], None
-        for line in lines:
-            match = re.search(_LINE_WITH_INDENT, line)
-            if re.search(_EMPTY_LINE, line):
-                _lines.append(line)
-                prev_indent = None
-            elif match:
-                indent, text = match.groups()
-                if prev_indent == indent:
-                    _prev = _lines[-1].rstrip()
-                    _lines[-1] = u"{0} {1}".format(_prev, text)
-                else:
-                    _lines.append(line)
-                prev_indent = indent
-            elif _lines[-1:]:
-                _lines[-1] = u"{0} {1}".format(_lines[-1].rstrip(), line)
-                prev_indent = None
-            else:
-                _lines.append(line)
-        return _lines
-
     def _call_for_paragraph(self, api_method, block_lines):
         api, indents, lines = None, [], []
-        for line in self._concatenate_paragraph_line(block_lines):
+        for line in concatenate_lines(block_lines, _LINE_WITH_INDENT_OR_NONE):
             match = re.search(_LINE_WITH_INDENT, line)
             indent, line = self._markup_notranslate(line, match)
             indents.append(indent)
             lines.append(line)
-        return self._call_keeping_prefix_with_array(api_method, indents, lines)
+        api, trans = self._call_keeping_prefix_with_array(api_method,
+                                                          indents, lines)
+        return api, self.split_lines_with_eos(trans)
 
     def call(self, api_method):
         for btype, block_lines, first in self.blocks:
