@@ -5,15 +5,15 @@ import argparse
 import os
 import sys
 
+from conf import (get_conf, get_conf_path)
 from core.translator import TRANSLATE_API
 from locale import _
 from utils import *
 
-__version__ = "0.4.0"
+__version__ = "0.4.1"
 
 def get_args():
-    _ver = "%(prog)s {0}".format(__version__)
-    parser = argparse.ArgumentParser(version=_ver)
+    parser = argparse.ArgumentParser()
     parser.set_defaults(api="google", detect=False, lang=False,
                         lang_from="en", lang_to=get_lang(),
                         po_file=None, rst_file=None, sentence=None,
@@ -39,6 +39,8 @@ def get_args():
                         metavar="SENTENCE", help=u"target sentences")
     parser.add_argument("-t", "--to", dest="lang_to", metavar="LANG",
                         help=u"target language to translate")
+    parser.add_argument("--version", action="version",
+                        version="%(prog)s {0}".format(__version__))
 
     opts = parser.parse_args()
     if not opts.lang_to:
@@ -54,7 +56,9 @@ def get_args():
     elif opts.encoding:
         err_encoding = check_encoding(opts.encoding)
         if err_encoding:
-            err_msg = _(u"unknown encodings: {0}").format(err_encoding)
+            err_msg = _(u"Unknown encodings: {0}").format(err_encoding)
+    elif not (opts.lang or opts.po_file or opts.rst_file or opts.sentences):
+        err_msg = _(u"Need to specify optional arguments")
 
     if err_msg:
         parser.print_help()
@@ -67,11 +71,15 @@ def get_args():
     return opts
 
 def main():
+    # pre process
+    check_python_version()
+    conf = get_conf(get_conf_path())
+    # main process
     opts = get_args()
     handler = get_handler(opts)
     t = TRANSLATE_API[opts.api](opts.lang_from, opts.lang_to, handler)
+    t.set_apikey_from_conf(conf)
     t.call_method_with_handler()
 
 if __name__ == "__main__":
-    check_python_version()
     main()
